@@ -1,4 +1,4 @@
-from python_api.debater_python_api.api.clients.key_point_analysis.KpAnalysisUtils import KpAnalysisUtils
+from debater_python_api.api.clients.key_point_analysis.KpAnalysisUtils import KpAnalysisUtils
 
 if __name__ == '__main__':
     KpAnalysisUtils.init_logger()
